local ModListWindow = {}

local _log = commonapi.utils.logPrep("commonapi.ui.ModListWindow")
local _utils = commonapi.utils
local _ = _utils._t
local ui = commonapi.ui;

local ModSettingsWindow = require("commonapi.ui.ModSettingsWindow")

ModListWindow = ui.Window:new()

ModListWindow.id = "ModListWindow"
ModListWindow.height = 300
ModListWindow.width = 300


ModListWindow.caption = _("Mod settings")

function ModListWindow.create()
    local o
    o = ModListWindow:new()
    o:genModUIList()
    o:open()
    return o
end


function ModListWindow:genDepWindow(modid)
	local uilist = {}


	local modentry = commonapi.mods.getById(modid)
	local requiredMods = modentry.data.info.requiredMods or {}

	local depwin = ui.Window:new()

	depwin.id = "ModDepWindow"
	depwin.caption = _("Mod dependencies:")

	for m, entry in pairs( requiredMods ) do

		local links = commonapi.mods._checkModDepends_createLinks(entry)

		local uimodid = {
			typ = "Label",
			caption = ""..(entry.modId or "No modId").." , "..(entry.steamId or "No SteamId")
		}
		uilist[#uilist+1] = uimodid
		local uiversion = {
			typ = "Label",
			caption = "\tMinorVersion: >="..(entry.minMinorVersion or 0)
		}
		uilist[#uilist+1] = uiversion

		for urltype, url in pairs( links ) do
			local urlentry = {
				typ = "Button",
				caption = urltype,
				sameline = true,
				id = ""..m..''..urltype,
				data = {
					myurl = url,
				},
				onclick = function(item, win)
					commonapi._native.utils.openurl(item.data.myurl)
				end
			}
			uilist[#uilist+1] = urlentry
		end
	end
	depwin.uilist = uilist

	depwin:open()
end

function ModListWindow:genModUIList()
	local uilist = {}
	local mods = commonapi.mods.getLoaded()

	local uicolumns = {
		typ = "Columns",
		count = 2,
		border = true,
	}
	uilist[#uilist+1] = uicolumns

	for m, entry in pairs( mods ) do
		local uientry = {
			typ = "Label",
			caption = entry.name,
			column = 0,
			rownew = true,
		}
		uilist[#uilist+1] = uientry

		local uientryButton = {
			typ = "Button",
			id = entry.id..'_settings',
			caption = _("Settings"),
			column = 1,
			data = {
				modid = entry.id,
			},
			onclick = function(item, win)
				local o = ModSettingsWindow.create(item.data.modid)
				o:open()
			end
		}

		if (commonapi.settings._getDescription(entry.id) ~= nil) then
			uilist[#uilist+1] = uientryButton
		end

		if (entry.data.info ~= nil and entry.data.info.requiredMods ~= nil) then
			local uidepButton = {
				typ = "Button",
				id = entry.id..'_dep',
				caption = _("Dep"),
				column = 1,
				sameline = true,
				data = {
					modid = entry.id,
				},
				onclick = function(item, win)
					win:genDepWindow(item.data.modid)
				end
			}
			uilist[#uilist+1] = uidepButton
		end
	end
	self.uilist = uilist
end






return ModListWindow